@@ -72,30 +72,33 @@ yaml_parser_load(yaml_parser_t *parser, yaml_document_t *document)
     assert(document);   /* Non-NULL document object is expected. */
 
     memset(document, 0, sizeof(yaml_document_t));
-    if (!STACK_INIT(parser, document->nodes, INITIAL_STACK_SIZE))
+    if (!STACK_INIT(parser, document->nodes, yaml_node_t*))
         goto error;
 
     if (!parser->stream_start_produced) {
-        if (!yaml_parser_parse(parser, &event)) goto error;
+        if (!yaml_parser_parse(parser, &event))
+            goto error;
         assert(event.type == YAML_STREAM_START_EVENT);
-                        /* STREAM-START is expected. */
+        /* STREAM-START is expected. */
     }
 
     if (parser->stream_end_produced) {
         return 1;
     }
 
-    if (!yaml_parser_parse(parser, &event)) goto error;
+    if (!yaml_parser_parse(parser, &event))
+        goto error;
     if (event.type == YAML_STREAM_END_EVENT) {
         return 1;
     }
 
-    if (!STACK_INIT(parser, parser->aliases, INITIAL_STACK_SIZE))
+    if (!STACK_INIT(parser, parser->aliases, yaml_alias_data_t*))
         goto error;
 
     parser->document = document;
 
-    if (!yaml_parser_load_document(parser, &event)) goto error;
+    if (!yaml_parser_load_document(parser, &event))
+        goto error;
 
     yaml_parser_delete_aliases(parser);
     parser->document = NULL;
@@ -286,24 +289,28 @@ yaml_parser_load_scalar(yaml_parser_t *parser, yaml_event_t *first_event)
     int index;
     yaml_char_t *tag = first_event->data.scalar.tag;
 
-    if (!STACK_LIMIT(parser, parser->document->nodes, INT_MAX-1)) goto error;
+    if (!STACK_LIMIT(parser, parser->document->nodes, INT_MAX-1))
+        goto error;
 
     if (!tag || strcmp((char *)tag, "!") == 0) {
         yaml_free(tag);
         tag = yaml_strdup((yaml_char_t *)YAML_DEFAULT_SCALAR_TAG);
-        if (!tag) goto error;
+        if (!tag)
+            goto error;
     }
 
     SCALAR_NODE_INIT(node, tag, first_event->data.scalar.value,
             first_event->data.scalar.length, first_event->data.scalar.style,
             first_event->start_mark, first_event->end_mark);
 
-    if (!PUSH(parser, parser->document->nodes, node)) goto error;
+    if (!PUSH(parser, parser->document->nodes, node))
+        goto error;
 
     index = parser->document->nodes.top - parser->document->nodes.start;
 
     if (!yaml_parser_register_anchor(parser, index,
-                first_event->data.scalar.anchor)) return 0;
+                first_event->data.scalar.anchor))
+        return 0;
 
     return index;
 
@@ -331,26 +338,31 @@ yaml_parser_load_sequence(yaml_parser_t *parser, yaml_event_t *first_event)
     int index, item_index;
     yaml_char_t *tag = first_event->data.sequence_start.tag;
 
-    if (!STACK_LIMIT(parser, parser->document->nodes, INT_MAX-1)) goto error;
+    if (!STACK_LIMIT(parser, parser->document->nodes, INT_MAX-1))
+        goto error;
 
     if (!tag || strcmp((char *)tag, "!") == 0) {
         yaml_free(tag);
         tag = yaml_strdup((yaml_char_t *)YAML_DEFAULT_SEQUENCE_TAG);
-        if (!tag) goto error;
+        if (!tag)
+            goto error;
     }
 
-    if (!STACK_INIT(parser, items, INITIAL_STACK_SIZE)) goto error;
+    if (!STACK_INIT(parser, items, yaml_node_item_t*))
+        goto error;
 
     SEQUENCE_NODE_INIT(node, tag, items.start, items.end,
             first_event->data.sequence_start.style,
             first_event->start_mark, first_event->end_mark);
 
-    if (!PUSH(parser, parser->document->nodes, node)) goto error;
+    if (!PUSH(parser, parser->document->nodes, node))
+        goto error;
 
     index = parser->document->nodes.top - parser->document->nodes.start;
 
     if (!yaml_parser_register_anchor(parser, index,
-                first_event->data.sequence_start.anchor)) return 0;
+                first_event->data.sequence_start.anchor))
+        return 0;
 
     if (!yaml_parser_parse(parser, &event)) return 0;
 
@@ -394,42 +406,52 @@ yaml_parser_load_mapping(yaml_parser_t *parser, yaml_event_t *first_event)
     yaml_node_pair_t pair;
     yaml_char_t *tag = first_event->data.mapping_start.tag;
 
-    if (!STACK_LIMIT(parser, parser->document->nodes, INT_MAX-1)) goto error;
+    if (!STACK_LIMIT(parser, parser->document->nodes, INT_MAX-1))
+        goto error;
 
     if (!tag || strcmp((char *)tag, "!") == 0) {
         yaml_free(tag);
         tag = yaml_strdup((yaml_char_t *)YAML_DEFAULT_MAPPING_TAG);
-        if (!tag) goto error;
+        if (!tag)
+            goto error;
     }
 
-    if (!STACK_INIT(parser, pairs, INITIAL_STACK_SIZE)) goto error;
+    if (!STACK_INIT(parser, pairs, yaml_node_pair_t*))
+        goto error;
 
     MAPPING_NODE_INIT(node, tag, pairs.start, pairs.end,
             first_event->data.mapping_start.style,
             first_event->start_mark, first_event->end_mark);
 
-    if (!PUSH(parser, parser->document->nodes, node)) goto error;
+    if (!PUSH(parser, parser->document->nodes, node))
+        goto error;
 
     index = parser->document->nodes.top - parser->document->nodes.start;
 
     if (!yaml_parser_register_anchor(parser, index,
-                first_event->data.mapping_start.anchor)) return 0;
+                first_event->data.mapping_start.anchor))
+        return 0;
 
-    if (!yaml_parser_parse(parser, &event)) return 0;
+    if (!yaml_parser_parse(parser, &event))
+        return 0;
 
     while (event.type != YAML_MAPPING_END_EVENT) {
         if (!STACK_LIMIT(parser,
                     parser->document->nodes.start[index-1].data.mapping.pairs,
-                    INT_MAX-1)) return 0;
+                    INT_MAX-1))
+            return 0;
         pair.key = yaml_parser_load_node(parser, &event);
         if (!pair.key) return 0;
-        if (!yaml_parser_parse(parser, &event)) return 0;
+        if (!yaml_parser_parse(parser, &event))
+            return 0;
         pair.value = yaml_parser_load_node(parser, &event);
-        if (!pair.value) return 0;
+        if (!pair.value)
+            return 0;
         if (!PUSH(parser,
                     parser->document->nodes.start[index-1].data.mapping.pairs,
                     pair)) return 0;
-        if (!yaml_parser_parse(parser, &event)) return 0;
+        if (!yaml_parser_parse(parser, &event))
+            return 0;
     }
 
     parser->document->nodes.start[index-1].end_mark = event.end_mark;
